@@ -367,13 +367,12 @@ L<SQL::Abstract>.
 As well as some PostgreSQL specific extensions added by L<SQL::Abstract::Pg>.
 
   # "insert into some_table (foo) values ('bar') on conflict do nothing"
-  $db->insert('some_table', {foo => 'bar'}, {on_conflict => \'do nothing'});
+  $db->insert('some_table', {foo => 'bar'}, {on_conflict => undef});
 
 Including operations commonly referred to as C<upsert>.
 
   # "insert into t (a) values ('b') on conflict (a) do update set a = 'c'"
-  $db->insert(
-    't', {a => 'b'}, {on_conflict => \['(a) do update set a = ?', 'c']});
+  $db->insert('t', {a => 'b'}, {on_conflict => [['a'], {a => 'c'}]);
 
 =head2 insert_p
 
@@ -503,6 +502,18 @@ L<SQL::Abstract>.
 
 As well as some PostgreSQL specific extensions added by L<SQL::Abstract::Pg>.
 
+  # "select foo as bar from some_table"
+  $db->select('some_table', [[foo => 'bar']]);
+
+  # "select extract(epoch from foo) as foo, bar from some_table"
+  $db->select('some_table', [\'extract(epoch from foo) as foo', 'bar']);
+
+  # "select * from foo join bar on (bar.foo_id = foo.id)"
+  $db->select(['foo', ['bar', foo_id => 'id']]);
+
+  # "select * from foo left join bar on (bar.foo_id = foo.id)"
+  $db->select(['foo', [-left => 'bar', foo_id => 'id']]);
+
   # "select * from some_table where foo = 'bar' order by id desc"
   $db->select('some_table', '*', {foo => 'bar'}, {order_by => {-desc => 'id'}});
 
@@ -512,6 +523,12 @@ As well as some PostgreSQL specific extensions added by L<SQL::Abstract::Pg>.
   # "select * from some_table where foo = 23 group by foo, bar"
   $db->select('some_table', '*', {foo => 23}, {group_by => ['foo', 'bar']});
 
+  # "select * from t where a = 'b' group by c having d = 'e'"
+  $db->select('t', '*', {a => 'b'}, {group_by => ['c'], having => {d => 'e'}});
+
+  # "select * from some_table where id = 1 for update"
+  $db->select('some_table', '*', {id => 1}, {for => 'update'});
+
   # "select * from some_table where id = 1 for update skip locked"
   $db->select('some_table', '*', {id => 1}, {for => \'update skip locked'});
 
